@@ -30,6 +30,7 @@ from semantic_release.errors import (
 )
 from semantic_release.gitproject import GitProject
 from semantic_release.globals import logger
+from semantic_release.hvcs.github import Github
 from semantic_release.hvcs.remote_hvcs_base import RemoteHvcsBase
 from semantic_release.version.algorithm import (
     next_version,
@@ -466,7 +467,12 @@ def version(  # noqa: C901
     major_on_zero = runtime.major_on_zero
     no_verify = runtime.no_git_verify
     opts = runtime.global_cli_options
-    gha_output = VersionGitHubActionsOutput(released=False)
+    gha_output = VersionGitHubActionsOutput(
+        hvcs_client
+        if isinstance(hvcs_client, Github)
+        else Github(hvcs_client.remote_url(use_token=False)),
+        released=False,
+    )
 
     forced_level_bump = None if not force_level else LevelBump.from_string(force_level)
     prerelease = is_forced_prerelease(
@@ -572,6 +578,12 @@ def version(  # noqa: C901
     if print_only or print_only_tag:
         return
 
+    # TODO: need a better way as this is inconsistent if releasing older version patches
+    if last_release := last_released(config.repo_dir, tag_format=config.tag_format):
+        # If we have a last release, we can set the previous version for the
+        # GitHub Actions output
+        gha_output.prev_version = last_release[1]
+
     with Repo(str(runtime.repo_dir)) as git_repo:
         release_history = ReleaseHistory.from_git_history(
             repo=git_repo,
@@ -641,6 +653,29 @@ def version(  # noqa: C901
             click.echo("Build failed, aborting release", err=True)
             ctx.exit(1)
 
+    license_cfg = runtime.project_metadata.get(
+        "license-expression",
+        runtime.project_metadata.get(
+            "license",
+            "",
+        ),
+    )
+
+    license_cfg = "" if not isinstance(license_cfg, (str, dict)) else license_cfg
+    license_cfg = (
+        license_cfg.get("text", "") if isinstance(license_cfg, dict) else license_cfg
+    )
+
+    gha_output.release_notes = release_notes = generate_release_notes(
+        hvcs_client,
+        release=release_history.released[new_version],
+        template_dir=runtime.template_dir,
+        history=release_history,
+        style=runtime.changelog_style,
+        mask_initial_release=runtime.changelog_mask_initial_release,
+        license_name="" if not isinstance(license_cfg, str) else license_cfg,
+    )
+
     project = GitProject(
         directory=runtime.repo_dir,
         commit_author=runtime.commit_author,
@@ -676,6 +711,9 @@ def version(  # noqa: C901
             noop=opts.noop,
         )
 
+        with Repo(str(runtime.repo_dir)) as git_repo:
+            gha_output.commit_sha = git_repo.head.commit.hexsha
+
     if push_changes:
         remote_url = runtime.hvcs_client.remote_url(
             use_token=not runtime.ignore_token_for_push
@@ -710,33 +748,6 @@ def version(  # noqa: C901
         logger.info("Remote does not support releases. Skipping release creation...")
         return
 
-    license_cfg = runtime.project_metadata.get(
-        "license-expression",
-        runtime.project_metadata.get(
-            "license",
-            "",
-        ),
-    )
-
-    if not isinstance(license_cfg, (str, dict)) or license_cfg is None:
-        license_cfg = ""
-
-    license_name = (
-        license_cfg.get("text", "")
-        if isinstance(license_cfg, dict)
-        else license_cfg or ""
-    )
-
-    release_notes = generate_release_notes(
-        hvcs_client,
-        release=release_history.released[new_version],
-        template_dir=runtime.template_dir,
-        history=release_history,
-        style=runtime.changelog_style,
-        mask_initial_release=runtime.changelog_mask_initial_release,
-        license_name=license_name,
-    )
-
     exception: Exception | None = None
     help_message = ""
     try:
